@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2010 - 2017, Met Office
+# (C) British Crown Copyright 2010 - 2018, Met Office
 #
 # This file is part of cf_units.
 #
@@ -59,6 +59,11 @@ class Test_unit__creation(unittest.TestCase):
         u = Unit('hours since 1970-01-01 00:00:00', calendar=calendar)
         self.assertEqual(u.calendar, calendar)
 
+    def test_calendar_alias(self):
+        calendar = unit.CALENDAR_NO_LEAP
+        u = Unit('hours since 1970-01-01 00:00:00', calendar=calendar)
+        self.assertEqual(u.calendar, unit.CALENDAR_365_DAY)
+
     def test_no_calendar(self):
         u = Unit('hours since 1970-01-01 00:00:00')
         self.assertEqual(u.calendar, unit.CALENDAR_GREGORIAN)
@@ -290,6 +295,10 @@ class Test_root(unittest.TestCase):
         u = Unit('volt^2')
         self.assertEqual(u.root(2), 'V')
 
+    def test_square_root_integer_float(self):
+        u = Unit('volt^2')
+        self.assertEqual(u.root(2.), 'V')
+
     def test_not_numeric(self):
         u = Unit('volt')
         with self.assertRaisesRegexp(TypeError, 'numeric type'):
@@ -297,7 +306,7 @@ class Test_root(unittest.TestCase):
 
     def test_not_integer(self):
         u = Unit('volt')
-        with self.assertRaisesRegexp(TypeError, 'int type .* required'):
+        with self.assertRaisesRegexp(TypeError, 'integer .* required'):
             u.root(1.2)
 
     def test_meaningless_operation(self):
@@ -312,7 +321,7 @@ class Test_root(unittest.TestCase):
 
     def test_no_unit(self):
         u = Unit('no unit')
-        with self.assertRaisesRegexp(ValueError, 'Cannot take the logarithm'):
+        with self.assertRaisesRegexp(ValueError, 'Cannot take the root'):
             u.root(2)
 
 
@@ -552,7 +561,7 @@ class Test_stringify(unittest.TestCase):
     def test___repr___time_unit(self):
         u = Unit("hours since 2007-01-15 12:06:00",
                  calendar=unit.CALENDAR_STANDARD)
-        exp = "Unit('hours since 2007-01-15 12:06:00', calendar='standard')"
+        exp = "Unit('hours since 2007-01-15 12:06:00', calendar='gregorian')"
         self.assertEqual(repr(u), exp)
 
 
@@ -645,6 +654,13 @@ class Test_convert(unittest.TestCase):
         result = u.convert(expected * 1609.344, v)
         np.testing.assert_array_equal(result, expected)
 
+    def test_convert_array_multidim(self):
+        u = Unit('meter')
+        v = Unit('mile')
+        expected = (np.arange(2, dtype=np.float32) + 1).reshape([1, 1, 2, 1])
+        result = u.convert(expected * 1609.344, v)
+        np.testing.assert_array_equal(result, expected)
+
     def test_incompatible_units(self):
         u = Unit('m')
         v = Unit('V')
@@ -843,6 +859,42 @@ class Test__inplace(unittest.TestCase):
         np.testing.assert_array_equal(orig, converted)
         self.assertTrue(np.may_share_memory(orig, converted))
 
+    def test_multidim_masked(self):
+        c = Unit('deg_c')
+        f = Unit('deg_f')
+
+        # Manufacture a Fortran-ordered nd array to be converted.
+        orig = np.ma.masked_array(np.arange(4, dtype=np.float32),
+                                  mask=[1, 0, 0, 1]).reshape([2, 2]).T
+
+        # Test arrays are not equal without inplace conversions.
+        converted = c.convert(orig, f)
+
+        msg = "Arrays are not equal"
+        with self.assertRaisesRegexp(AssertionError, msg):
+            np.testing.assert_array_equal(orig.data, converted.data)
+        self.assertFalse(np.may_share_memory(orig, converted))
+
+        # Test inplace conversion alters the original array.
+        converted = c.convert(orig, f, inplace=True)
+        np.testing.assert_array_equal(orig.data, converted.data)
+        self.assertTrue(np.may_share_memory(orig, converted))
+
+    def test_foreign_endian(self):
+        c = Unit('deg_c')
+        f = Unit('deg_f')
+
+        # Manufacture a non-native byte-order array to be converted.
+        orig = np.arange(4, dtype=np.float32).newbyteorder().byteswap()
+
+        msg = ('Unable to convert non-native byte ordered array in-place. '
+               'Consider byte-swapping first.')
+        with self.assertRaisesRegexp(ValueError, msg):
+            converted = c.convert(orig, f, inplace=True)
+
+        # Test we can do this when not-inplace
+        c.convert(orig, f)
+
 
 class TestTimeEncoding(unittest.TestCase):
 
